summaryrefslogtreecommitdiffstats
path: root/content/renderer/render_widget.h
diff options
context:
space:
mode:
authorpenghuang@chromium.org <penghuang@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-10-16 01:13:00 +0000
committerpenghuang@chromium.org <penghuang@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-10-16 01:13:00 +0000
commite99ef6f2171118d5489d43f505f13909fdfcb18d (patch)
treebfda1adc527f4a8b2981b138d2e11801de31dc40 /content/renderer/render_widget.h
parentb97d770971011a355ba004d27365f4a81f47d516 (diff)
downloadchromium_src-e99ef6f2171118d5489d43f505f13909fdfcb18d.zip
chromium_src-e99ef6f2171118d5489d43f505f13909fdfcb18d.tar.gz
chromium_src-e99ef6f2171118d5489d43f505f13909fdfcb18d.tar.bz2
Refactor SelectionChanged and ImeUpdateTextInputType IPCs for surrounding text features
BUG=None TEST=Manually Review URL: http://codereview.chromium.org/7981036 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@105699 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'content/renderer/render_widget.h')
-rw-r--r--content/renderer/render_widget.h13
1 files changed, 9 insertions, 4 deletions
diff --git a/content/renderer/render_widget.h b/content/renderer/render_widget.h
index 1a900ca..44a1106 100644
--- a/content/renderer/render_widget.h
+++ b/content/renderer/render_widget.h
@@ -281,9 +281,13 @@ class CONTENT_EXPORT RenderWidget
void set_next_paint_is_restore_ack();
void set_next_paint_is_repaint_ack();
// Checks if the input method state and caret position have been changed.
// If they are changed, the new value will be sent to the browser process.
- void UpdateInputMethod();
+ void UpdateTextInputState();
+
+ // Checks if the selection bounds have been changed. If they are changed,
+ // the new value will be sent to the browser process.
+ void UpdateSelectionBounds();
// Override point to obtain that the current input method state and caret
// position.
@@ -430,8 +434,9 @@ class CONTENT_EXPORT RenderWidget
// Stores the current type of composition text rendering of |webwidget_|.
bool can_compose_inline_;
- // Stores the current caret bounds of input focus.
- WebKit::WebRect caret_bounds_;
+ // Stores the current selection bounds.
+ gfx::Rect selection_start_rect_;
+ gfx::Rect selection_end_rect_;
// The kind of popup this widget represents, NONE if not a popup.
WebKit::WebPopupType popup_type_;
@@ -281,9 +281,13 @@ class CONTENT_EXPORT RenderWidget
void set_next_paint_is_restore_ack();
void set_next_paint_is_repaint_ack();
- // Checks if the input method state and caret position have been changed.
+ // Checks if the text input state and compose inline mode have been changed.
// If they are changed, the new value will be sent to the browser process.